% this script sets up the LTE and 5G personalities in the FSW
% for LTE, only the first frame of four is measured
% for 5G, payloads across all four frames are measured


indexMBSFN = 0; % pointer to MBSFN slot/subframe 1~24

% prepare the FSW with a series of commands
parseSCPIFile(rscFSW,'setup_4framesMBSFN_FSW.scpi',1,0);

f = waitbar(0, 'Configuring frames... ');

% loop through each frame and slot
% look up whether LTE or 5G is scheduled
% swtich between each personality, and program according to needs
for numFrame = 1:4
   
    waitbar(numFrame/4, f, 'Configuring frames... ');
    % simplify the SCPI command for the 5G personality
    rscStringFSW5GNR_2 = [':CONF:NR5G:DL:CC1:FRAM' num2str(numFrame) ':BWP0'];

    % set the template (RBs, etc) for the 5G slots to be used
    sendSCPIcmd(rscFSW,[rscStringFSW5GNR_2 ':SSP SS15'],1,0);
    sendSCPIcmd(rscFSW,[rscStringFSW5GNR_2 ':RBC 25'],1,0);
    sendSCPIcmd(rscFSW,[rscStringFSW5GNR_2 ':CSL 10'],1,0);
    sendSCPIcmd(rscFSW,[rscStringFSW5GNR_2 ':SLOT:PAST:ALL'],1,0);
    
    % blank out all slots in the frame, pending writing of active 5G slots
    sendSCPIcmd(rscFSW,[rscStringFSW5GNR_2 ':SLOT0:ATYP UNUS'],1,0);
    sendSCPIcmd(rscFSW,[rscStringFSW5GNR_2 ':SLOT0:COPY'],1,0);
    sendSCPIcmd(rscFSW,[rscStringFSW5GNR_2 ':SLOT:PAST:ALL'],1,0);
    
    
    % cycle through each slot, and program according to LTE or 5G
    for subframeDummy = 0:9
        
        % establish whether this is 5G or LTE.
        is5G = '0';
        subframetoWrite = (10*(numFrame-1)) + subframeDummy;

        if ismember(subframetoWrite, sfMBSFN)
            indexMBSFN = indexMBSFN + 1;
            is5G = binMBSFN(indexMBSFN);
        end
        
        waitbar( indexMBSFN/24, f, 'Configuring frames... ');
        
        % create a new resource string
        rscStringFSW5GNR = [':CONF:NR5G:DL:CC1:FRAM' num2str(numFrame) ':BWP0:SLOT' num2str(subframeDummy)];

        if is5G == '1'  % is it a 5G payload?
            
            % LTE is only set-up to be measured in the first frame
            if numFrame==1
                % FSW LTE (set MBSFN, so that LTE ignores this slot)
                sendSCPIcmd(rscFSW,':INST:SEL "LTE"',1,0);
                sendSCPIcmd(rscFSW,[':CONF:LTE:DL:CC:MBSF:SUBF' num2str(subframeDummy) ':STAT ON'],1,0);
                sendSCPIcmd(rscFSW,[':CONF:LTE:DL:CC:SUBF' num2str(subframeDummy) ':ALC 0'],1,0);
            end
            
            % FSW 5GNR (set up the 5G payload)
            sendSCPIcmd(rscFSW,':INST:SEL "5G NR"',1,0);
            sendSCPIcmd(rscFSW, [rscStringFSW5GNR ':ATYP DATA'],1,0);
            sendSCPIcmd(rscFSW, [rscStringFSW5GNR ':ALL0:CW:MOD QAM64'],1,0);
            sendSCPIcmd(rscFSW, [rscStringFSW5GNR ':ALL0:SCO 12'],1,0);
            sendSCPIcmd(rscFSW, [rscStringFSW5GNR ':ALL0:SOFF 2'],1,0);
            sendSCPIcmd(rscFSW, [rscStringFSW5GNR ':COR0:RBC 6'],1,0);
            sendSCPIcmd(rscFSW, [rscStringFSW5GNR ':COR0:SOFF 1'],1,0);
        
        
        else    % if it's not 5G, it must be LTE...
            
            % FSW LTE (measure LTE, if it's LTE and the first frame)
            if numFrame==1
                sendSCPIcmd(rscFSW,':INST:SEL "DSS_LTE"',1,0);
                sendSCPIcmd(rscFSW,[':CONF:LTE:DL:CC:MBSF:SUBF' num2str(subframeDummy) ':STAT OFF'],1,0);
                sendSCPIcmd(rscFSW,[':CONF:LTE:DL:CC:SUBF' num2str(subframeDummy) ':ALC 1'],1,0);
                sendSCPIcmd(rscFSW,[':CONF:LTE:DL:CC:SUBF' num2str(subframeDummy) ':ALL0:CW1:MOD QAM16'],1,0);
                sendSCPIcmd(rscFSW,[':CONF:LTE:DL:CC:SUBF' num2str(subframeDummy) ':ALL0:RBC 25'],1,0);
                sendSCPIcmd(rscFSW,[':CONF:LTE:DL:CC:SUBF' num2str(subframeDummy) ':ALL0:RBO 0'],1,0);
                sendSCPIcmd(rscFSW,[':CONF:LTE:DL:CC:SUBF' num2str(subframeDummy) ':ALL0:POW 0'],1,0);
            end
            
            % FSW 5GNR (don't try to measure 5G if it's LTE)
            sendSCPIcmd(rscFSW,':INST:SEL "DSS_5G_NR"',1,0);
            sendSCPIcmd(rscFSW, [rscStringFSW5GNR ':ATYP UNUS'],1,0);
        end
    end
end

close(f);

% finally, trigger both personalities to run continuously
sendSCPIcmd(rscFSW,':INST:SEL "DSS_5G_NR"',1,0);
sendSCPIcmd(rscFSW,':INIT:CONT ON',1,0);
sendSCPIcmd(rscFSW,':INST:SEL "DSS_LTE"',1,0);
sendSCPIcmd(rscFSW,':INIT:CONT ON',1,0);