%% This script, step 1 of 3, sets up instrument IP resources, needed paths and different methods for MBSFN generation

clear; close all;

%% Equipment resources, for use with the VISA_Instrument class
% modify these resource strings to the addresses of the implemented
% instruments
global rscSMW rscFSW;
rscSMW = 'TCPIP::10.202.0.143::INSTR';
rscFSW = 'TCPIP::10.202.0.116::INSTR';

% Paths to needed files and functions
% the provided files may be distributed to these directories
addpath ./scpi_files
addpath ./functions

%% Generate the MBSFN 4 frame payload schedule
% initially a 24-bit sequence, with '1' representing 5G payloads, and '0'
% representing LTE.


% preferred case, e.g. ESS, HEX = C00800
cfgMBSFN = dec2bin(12584960); 

% decomment the following cfgMBSFN parameter to generate a random pattern
%cfgMBSFN = ([dec2bin(power(2,23)+(power(2,23)*rand())+1)]);


% ensure that the 13th (from 24) bit is set to 5G
cfgMBSFN(13) = '1';

% convert to decimal, to send to the SMW via SCPI
% front panel, manual entry, is HEX
cfgMBSFN = bin2dec(cfgMBSFN);

% pre-processing of parameters
% set up four frames capable of MBSFN
% in each of the four frames, there are 6 positions which are specified as potential
% carriers of 5G
sfMBSFN = [1 2 3 6 7 8];
sfMBSFN = [sfMBSFN sfMBSFN+10 sfMBSFN+20 sfMBSFN+30];
nMBSFN = length(sfMBSFN);

% resolve cfgMBSFN into subframes/slots
binMBSFN = dec2bin(cfgMBSFN,nMBSFN);

% map and pad the MBSFN subframes into LTE subframe schedule
% this creates a 38 slot schedule, starting from the second slot, finishing
% in the penultimate slot
padMBSFN = [binMBSFN(1:3) '00' binMBSFN(4:6) '00' binMBSFN(7:9) '00' binMBSFN(10:12) '00' binMBSFN(13:15) '00' binMBSFN(16:18) '00' binMBSFN(19:21) '00' binMBSFN(22:24)];