% this script sets up the SMW to create a DSS/MBSFN signal
% a sequence of 4 LTE frames, partially equipped with 5G payloads

indexMBSFN = 0;

% initialise the instrument, prepare the MBSFN schedule
parseSCPIFile(rscSMW,'setup_4framesMBSFN_SMW_1.scpi',1,1);
sendSCPIcmd(rscSMW,[':SOURce2:BB:EUTRa:DL:MBSFn:SC:AVAL ' num2str(cfgMBSFN)],1,0);
parseSCPIFile(rscSMW,'setup_4framesMBSFN_SMW_2.scpi',1,0);

f = waitbar(0, 'Configuring frames... ');

% configure each of the 39 slots in turn, for either LTE or 5G
for subframetoWrite = 1:39
    

    waitbar(subframetoWrite/39, f, 'Configuring frames... ');
    
    % default value is LTE
    is5G = '0';
    
    % check if the current slot/subframe is MBSFN
    % and then check if it is scheduled for LTE or 5G
    % otherwise, it's LTE
    if ismember(subframetoWrite, sfMBSFN)
        indexMBSFN = indexMBSFN + 1;
        is5G = binMBSFN(indexMBSFN);
    end
    
    % some resource strings to reduce verbosity in SCPI
    rscStringSMWLTE = [':SOURce2:BB:EUTRa:DL:SUBF' num2str(subframetoWrite)];
    rscStringSMW5GNR = [':SOURce1:BB:NR5G:SCHed:CELL0:SUBF' num2str(subframetoWrite) ':USER0:BWPart0'];
    rscStringFSW5GNR = [':CONF:NR5G:DL:CC1:FRAM1:BWP0:SLOT' num2str(subframetoWrite)];
    
    % On a subframe-by-subframe basis
    if (is5G == '0')
    
        % it's LTE!
        % is it the first subframe in a frame?
        % if so, it needs a different configuration
        if mod(subframetoWrite,10) ~= 0
            sendSCPIcmd(rscSMW,[rscStringSMWLTE ':ALCount 2'],1,0);
            sendSCPIcmd(rscSMW,[rscStringSMWLTE ':ALLoc1:CW1:MODulation QAM16'],1,0);
            sendSCPIcmd(rscSMW,[rscStringSMWLTE ':ALLoc1:CW1:RBCount 25'],1,0);
                    
        % otherwise, just write a regular LTE payload
        else
            sendSCPIcmd(rscSMW,[rscStringSMWLTE ':ALCount 3'],1,0);
            sendSCPIcmd(rscSMW,[rscStringSMWLTE ':ALLoc2:CW1:MODulation QAM16'],1,0);
            sendSCPIcmd(rscSMW,[rscStringSMWLTE ':ALLoc2:CW1:RBCount 25'],1,0);
            % update the user with this occassional progress report...

        end
        
        % SMW_5GNR
        %   there's nothing needed for 5G, the subframe stays empty
               
    else
        % SMW LTE
        %   this is a 5G payload, no LTE configuration necessary
        %   already taken care of by the MBSFN scheduling
        
        % SMW 5G NR
        %   this is scheduled for a 5G payload, create one
        sendSCPIcmd(rscSMW,[rscStringSMW5GNR ':NALLoc 2'],1,0);
        sendSCPIcmd(rscSMW,[rscStringSMW5GNR ':ALLoc0:CONTent COR'],1,0);
        sendSCPIcmd(rscSMW,[rscStringSMW5GNR ':ALLoc0:SYMoffset 1'],1,0);
        sendSCPIcmd(rscSMW,[rscStringSMW5GNR ':ALLoc0:RBNumber 6'],1,0);
        sendSCPIcmd(rscSMW,[rscStringSMW5GNR ':ALLoc0:REPetitions OFF'],1,0);
        sendSCPIcmd(rscSMW,[rscStringSMW5GNR ':ALLoc1:SYMNumber 12'],1,0);
        sendSCPIcmd(rscSMW,[rscStringSMW5GNR ':ALLoc1:SYMoffset 2'],1,0);
        sendSCPIcmd(rscSMW,[rscStringSMW5GNR ':ALLoc1:REPetitions OFF'],1,0);
        sendSCPIcmd(rscSMW,[rscStringSMW5GNR ':ALLoc1:CW0:MOD QAM64'],1,0);
        
    end

end

close(f)

fprintf ('Compiling the signal...');
% all slots/subframes are programmed, now compile the basebands and trigger
sendSCPIcmd(rscSMW,':SOURce2:BB:EUTRa:STATe 1',1,0);
sendSCPIcmd(rscSMW,':SOURce1:BB:NR5G:STATe 1',1,0);
sendSCPIcmd(rscSMW,':SOURce1:BB:NR5G:TRIGger:EXECute',1,0);
fprintf (' job done.\n');